@@ -64,8 +64,12 @@
 #define ANJUTA_PIXMAP_PASSWORD "password.png"
 #define FILE_BUFFER_SIZE 1024
 #ifndef __MAX_BAUD
+#ifdef __CYGWIN__
+#define __MAX_BAUD B256000
+#else
 #define __MAX_BAUD B460800
 #endif
+#endif
 
 /*
 static gboolean
@@ -857,13 +861,18 @@ static void
 anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 										gboolean emit_signal)
 {
+	static gboolean block = FALSE;
 	gint child_status, child_pid;
 	time_t start_time;
 	
 	if (launcher->priv->completion_check_timeout >= 0)
 		g_source_remove (launcher->priv->completion_check_timeout);
-
+	
+	if (block)
+		return;
+	
 	/* Make sure all pending I/O are flushed out */
+	block = TRUE;
 	while (g_main_context_pending (NULL))
 		g_main_context_iteration (NULL, FALSE);
 	
@@ -917,6 +926,8 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 		g_signal_emit_by_name (launcher, "child-exited", child_pid,
 							   child_status,
 							   time (NULL) - start_time);
+		
+	block = FALSE;
 }
 
 /* Using this function is necessary because
@@ -960,6 +971,8 @@ anjuta_launcher_child_terminated (int status, gpointer data)
 {
 	AnjutaLauncher *launcher = data;
 	
+	g_return_if_fail(ANJUTA_IS_LAUNCHER(launcher));
+	
 	/* Save child exit code */
 	launcher->priv->child_status = status;
 	launcher->priv->child_has_terminated = TRUE;
@@ -1089,7 +1102,10 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, gchar *const args[])
 
 	if (!launcher->priv->terminal_echo_on)
 	{
-		termios_flags.c_lflag &= ~(ECHOKE | ECHOE | ECHO | ECHONL | ECHOPRT |
+		termios_flags.c_lflag &= ~(ECHOKE | ECHOE | ECHO | ECHONL | 
+#ifdef ECHOPRT
+						ECHOPRT |
+#endif
 						ECHOCTL | ISIG | ICANON | IEXTEN | NOFLSH | TOSTOP);
 	}
 //	termios_flags.c_lflag |= 0;
@@ -1202,6 +1218,41 @@ anjuta_launcher_execute (AnjutaLauncher *launcher, const gchar *command_str,
 	return ret;
 }
 
+/**
+ * anjuta_launcher_set_buffered_output:
+ * @launcher: a #AnjutaLancher object.
+ * @buffered: buffer output.
+ * 
+ * Sets if output should buffered or not. By default, it is buffered.
+ *
+ * Return value: Previous flag value
+ */
+gboolean
+anjuta_launcher_set_buffered_output (AnjutaLauncher *launcher, gboolean buffered)
+{
+	gboolean past_value = launcher->priv->buffered_output;
+	launcher->priv->buffered_output = buffered;
+	return past_value;
+}
+
+/**
+ * anjuta_launcher_set_check_passwd_prompt:
+ * @launcher: a #AnjutaLancher object.
+ * @check_passwd: check for password.
+ * 
+ * Set if output is checked for a password prompti. A special dialog box
+ * is use to enter it in this case. By default, this behavior is enabled.
+ *
+ * Return value: Previous flag value
+ */
+gboolean
+anjuta_launcher_set_check_passwd_prompt (AnjutaLauncher *launcher, gboolean check_passwd)
+{
+	gboolean past_value = launcher->priv->check_for_passwd_prompt;
+	launcher->priv->check_for_passwd_prompt = check_passwd;
+	return past_value;
+}
+
 /**
  * anjuta_launcher_set_terminal_echo:
  * @launcher: a #AnjutaLancher object.
@@ -1233,11 +1284,13 @@ anjuta_launcher_set_terminal_echo (AnjutaLauncher *launcher,
  *
  * Return value: Previous flag value
  */
-void
+gboolean
 anjuta_launcher_set_terminate_on_exit (AnjutaLauncher *launcher,
 						gboolean terminate_on_exit)
 {
+	gboolean past_value = launcher->priv->terminate_on_exit;
 	launcher->priv->terminate_on_exit = terminate_on_exit;
+	return past_value;
 }
 
 /**
