@@ -21,20 +21,27 @@
 #define LIBANJUTA_H
 
 /* FIXME: Update required */
-#include <libanjuta/anjuta-debug.h>
-#include <libanjuta/anjuta-utils.h>
-#include <libanjuta/anjuta-plugin.h>
-#include <libanjuta/anjuta-plugin-description.h>
-#include <libanjuta/anjuta-preferences.h>
-#include <libanjuta/anjuta-ui.h>
-#include <libanjuta/anjuta-status.h>
-#include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-children.h>
-#include <libanjuta/anjuta-launcher.h>
-#include <libanjuta/anjuta-serializer.h>
-#include <libanjuta/anjuta-save-prompt.h>
+#include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-encodings.h>
+#include <libanjuta/anjuta-enum-types.h>
+#include <libanjuta/anjuta-launcher.h>
 #include <libanjuta/anjuta-marshal.h>
+#include <libanjuta/anjuta-plugin-description.h>
+#include <libanjuta/anjuta-plugin.h>
+#include <libanjuta/anjuta-plugin-handle.h>
+#include <libanjuta/anjuta-plugin-manager.h>
+#include <libanjuta/anjuta-preferences-dialog.h>
+#include <libanjuta/anjuta-preferences.h>
+#include <libanjuta/anjuta-profile.h>
+#include <libanjuta/anjuta-profile-manager.h>
+#include <libanjuta/anjuta-save-prompt.h>
+#include <libanjuta/anjuta-serializer.h>
+#include <libanjuta/anjuta-session.h>
+#include <libanjuta/anjuta-shell.h>
+#include <libanjuta/anjuta-status.h>
+#include <libanjuta/anjuta-ui.h>
+#include <libanjuta/anjuta-utils.h>
 #include <libanjuta/resources.h>
 
 #endif
