@@ -83,6 +83,20 @@ static GtkActionEntry actions_goto[] = {
     G_CALLBACK (on_save_message)}
 };
 
+static void on_view_changed(AnjutaMsgman* msgman, MessageViewPlugin* plugin)
+{
+	AnjutaUI* ui = anjuta_shell_get_ui (ANJUTA_PLUGIN(plugin)->shell, NULL);
+	GtkAction* action_next = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessageNext");
+	GtkAction* action_prev = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessagePrev");
+	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
+								 GTK_WIDGET(msgman), NULL);
+	gboolean sensitive = (anjuta_msgman_get_current_view(msgman) != NULL);
+	g_object_set (G_OBJECT (action_next), "sensitive", sensitive, NULL);
+	g_object_set (G_OBJECT (action_prev), "sensitive", sensitive, NULL);
+}
+
 static gpointer parent_class;
 
 #define REGISTER_ICON(icon, stock_id) \
@@ -211,7 +225,17 @@ activate_plugin (AnjutaPlugin *plugin)
 											GETTEXT_PACKAGE, TRUE, plugin);
 	mv_plugin->uiid = anjuta_ui_merge (ui, UI_FILE);
 	popup = gtk_ui_manager_get_widget (GTK_UI_MANAGER (ui), "/PopupMessageView");
-	mv_plugin->msgman = anjuta_msgman_new(anjuta_shell_get_preferences(plugin->shell, NULL), popup);
+	mv_plugin->msgman = 
+		anjuta_msgman_new(anjuta_shell_get_preferences(plugin->shell, NULL), popup);
+	g_signal_connect(G_OBJECT(mv_plugin->msgman), "view_changed", 
+					 G_CALLBACK(on_view_changed), mv_plugin);
+	GtkAction* action_next = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessageNext");
+	GtkAction* action_prev = anjuta_ui_get_action (ui, "ActionGroupGotoMessages",
+								   "ActionMessagePrev");
+	g_object_set (G_OBJECT (action_next), "sensitive", FALSE, NULL);
+	g_object_set (G_OBJECT (action_prev), "sensitive", FALSE, NULL);
+	
 	anjuta_shell_add_widget (plugin->shell, mv_plugin->msgman,
 							 "AnjutaMessageView", _("Messages"),
 							 "message-manager-plugin-icon",
@@ -302,8 +326,6 @@ ianjuta_msgman_add_view (IAnjutaMessageManager *plugin,
 	MessageView* message_view;
 	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
 	message_view = anjuta_msgman_add_view (ANJUTA_MSGMAN (msgman), file, icon);
-	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
-								 msgman, NULL);
 	return IANJUTA_MESSAGE_VIEW (message_view);
 }
 
@@ -350,14 +372,11 @@ ianjuta_msgman_set_current_view (IAnjutaMessageManager *plugin,
 {
 	AnjutaShell* shell;
 	GtkWidget *msgman = ANJUTA_PLUGIN_MESSAGE_VIEW (plugin)->msgman;
-	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
-								 msgman, NULL);
 	anjuta_msgman_set_current_view (ANJUTA_MSGMAN (msgman),
 					       MESSAGE_VIEW (message_view));
 	
 	/* Ensure the message-view is visible! */
 	g_object_get(G_OBJECT(plugin), "shell", &shell, NULL);
-	anjuta_shell_present_widget(shell, GTK_WIDGET(msgman), NULL);
 }
 
 static void
