@@ -55,12 +55,8 @@
 #include "anjuta-view.h"
 
 #include "sourceview.h"
-#include "sourceview-prefs.h"
-#include "sourceview-autocomplete.h"
 #include "sourceview-private.h"
-#include "sourceview-tags.h"
-#include "sourceview-scope.h"
-#include "sourceview-args.h"
+#include "sourceview-prefs.h"
 #include "sourceview-print.h"
 #include "sourceview-cell.h"
 #include "plugin.h"
@@ -75,7 +71,7 @@ static void sourceview_instance_init(Sourceview *sv);
 static void sourceview_finalize(GObject *object);
 static GObjectClass *parent_class = NULL;
 
-static void sourceview_add_monitor(Sourceview* sv);
+static gboolean sourceview_add_monitor(Sourceview* sv);
 
 /* Callbacks */
 
@@ -130,44 +126,22 @@ sourceview_remove_monitor(Sourceview* sv)
 	}
 }
 
-/* VFS-Monitor Callback */
-static void
-on_sourceview_uri_changed (GnomeVFSMonitorHandle *handle,
-							const gchar *monitor_uri,
-							const gchar *info_uri,
-							GnomeVFSMonitorEventType event_type,
-							gpointer user_data)
+static gboolean
+on_sourceview_uri_changed_prompt (Sourceview* sv)
 {
 	GtkWidget *dlg;
+	GtkWidget *parent;
 	gchar *buff;
-	Sourceview *sv = ANJUTA_SOURCEVIEW (user_data);
-	
-	DEBUG_PRINT ("File changed!!!");
-	
-	if (!(event_type == GNOME_VFS_MONITOR_EVENT_CHANGED ||
-		  event_type == GNOME_VFS_MONITOR_EVENT_CREATED))
-		return;
-	
-	sourceview_remove_monitor(sv);
-	
-	if (!anjuta_util_diff(anjuta_document_get_uri(sv->priv->document), 
-						  ianjuta_editor_get_text(IANJUTA_EDITOR(sv),
-												  0, -1, NULL)))
-	{
-		sourceview_add_monitor(sv);
-		return;
-	}
-	
-	if (strcmp (monitor_uri, info_uri) != 0)
-		return;
 	
 	buff =
 		g_strdup_printf (_
 						 ("The file '%s' on the disk is more recent than\n"
 						  "the current buffer.\nDo you want to reload it?"),
-						 g_basename(anjuta_document_get_uri(sv->priv->document)));
+						 ianjuta_editor_get_filename(IANJUTA_EDITOR(sv), NULL));
 	
-	dlg = gtk_message_dialog_new (NULL,
+	parent = gtk_widget_get_toplevel (GTK_WIDGET (sv));
+	
+	dlg = gtk_message_dialog_new (GTK_WINDOW (parent),
 								  GTK_DIALOG_DESTROY_WITH_PARENT,
 								  GTK_MESSAGE_WARNING,
 								  GTK_BUTTONS_NONE, buff);
@@ -180,28 +154,60 @@ on_sourceview_uri_changed (GnomeVFSMonitorHandle *handle,
 								   GTK_RESPONSE_YES);
 	g_free (buff);
 	
-	g_signal_connect (dlg, "response",
+	gtk_window_set_transient_for (GTK_WINDOW (dlg),
+								  GTK_WINDOW (parent));
+	
+	g_signal_connect (G_OBJECT(dlg), "response",
 					  G_CALLBACK (on_reload_dialog_response),
 					  sv);
-	g_signal_connect_swapped (dlg, "delete-event",
+	gtk_widget_show (dlg);
+
+	g_signal_connect_swapped (G_OBJECT(dlg), "delete-event",
 					  G_CALLBACK (gtk_widget_destroy),
 					  dlg);
-	gtk_widget_show (dlg);
+	
+	return FALSE;
 }
 
-static void 
+static void
+on_sourceview_uri_changed (GnomeVFSMonitorHandle *handle,
+							const gchar *monitor_uri,
+							const gchar *info_uri,
+							GnomeVFSMonitorEventType event_type,
+							gpointer user_data)
+{
+	Sourceview *sv = ANJUTA_SOURCEVIEW (user_data);
+	
+	if (!(event_type == GNOME_VFS_MONITOR_EVENT_CHANGED ||
+		  event_type == GNOME_VFS_MONITOR_EVENT_CREATED))
+		return;
+	
+	if (!anjuta_util_diff (anjuta_document_get_uri(sv->priv->document), sv->priv->last_saved_content))
+	{
+		return;
+	}
+	
+	
+	if (strcmp (monitor_uri, info_uri) != 0)
+		return;
+	
+	on_sourceview_uri_changed_prompt(sv);	
+}
+
+static gboolean 
 sourceview_add_monitor(Sourceview* sv)
 {
 	gboolean monitor_enabled = anjuta_preferences_get_int (sv->priv->prefs, MONITOR_KEY);
 
 	if (monitor_enabled)
 	{
-		g_return_if_fail(sv->priv->monitor == NULL);
-		DEBUG_PRINT ("Monitor added for %s", anjuta_document_get_uri(sv->priv->document)); 
+		g_return_val_if_fail(sv->priv->monitor == NULL, FALSE);
+		DEBUG_PRINT ("Monitor added for %s", anjuta_document_get_uri(sv->priv->document)); 	
 		gnome_vfs_monitor_add(&sv->priv->monitor, anjuta_document_get_uri(sv->priv->document),
 							  GNOME_VFS_MONITOR_FILE,
 						  on_sourceview_uri_changed, sv);
 	}
+	return FALSE; /* for g_idle_add */
 }
 
 /* Called when document is loaded completly */
@@ -229,6 +235,9 @@ static void on_document_loaded(AnjutaDocument* doc, GError* err, Sourceview* sv)
 
 	lang = ianjuta_editor_language_get_language(IANJUTA_EDITOR_LANGUAGE(sv), NULL);
 	g_signal_emit_by_name (sv, "language-changed", lang);
+	
+	/* Get rid of reference from ifile_open */
+	g_object_unref(G_OBJECT(sv));
 }
 
 /* Show nice progress bar */
@@ -295,6 +304,13 @@ static gboolean save_if_modified(AnjutaDocument* doc, GtkWindow* parent)
    	}
 }
 
+/* Need to avoid crash when unref is done before add_monitor */
+static gboolean timeout_unref(Sourceview* sv)
+{
+	g_object_unref(G_OBJECT(sv));
+	return FALSE;
+}
+
 /* Called when document is saved completly */
 static void on_document_saved(AnjutaDocument* doc, GError* err, Sourceview* sv)
 {
@@ -322,9 +338,14 @@ static void on_document_saved(AnjutaDocument* doc, GError* err, Sourceview* sv)
 	{
 		gtk_text_buffer_set_modified(GTK_TEXT_BUFFER(doc), FALSE);
 		g_signal_emit_by_name(G_OBJECT(sv), "save_point", TRUE);
-		sourceview_add_monitor(sv);
+		/* Set up 2 sec timer */
+		if (sv->priv->monitor_delay > 0)
+ 			g_source_remove (sv->priv->monitor_delay);
+		sv->priv->monitor_delay = g_timeout_add (2000,
+							(GSourceFunc)sourceview_add_monitor, sv);
 		sv->priv->saving = FALSE;
 	}
+	g_timeout_add(3000, (GSourceFunc)timeout_unref, sv);
 }
 
 static void 
@@ -352,14 +373,12 @@ sourceview_finalize(GObject *object)
 	Sourceview *cobj;
 	cobj = ANJUTA_SOURCEVIEW(object);
 	
-	/* Free private members, etc. */
+	DEBUG_PRINT("=========== finalise =============");
 	
 	sourceview_remove_monitor(cobj);
+	sourceview_prefs_destroy(cobj);
 	
-	gtk_widget_destroy(GTK_WIDGET(cobj->priv->tag_window));
-	gtk_widget_destroy(GTK_WIDGET(cobj->priv->autocomplete));
-	gtk_widget_destroy(GTK_WIDGET(cobj->priv->args));
-	gtk_widget_destroy(GTK_WIDGET(cobj->priv->scope));
+	g_object_unref(cobj->priv->view);
 	
 	g_free(cobj->priv);
 	G_OBJECT_CLASS(parent_class)->finalize(object);
@@ -475,14 +494,10 @@ sourceview_new(const gchar* uri, const gchar* filename, AnjutaPlugin* plugin)
 	g_signal_connect_after(G_OBJECT(sv->priv->view), "char_added",
 					G_CALLBACK(on_document_char_added), sv);
 	gtk_source_view_set_smart_home_end(GTK_SOURCE_VIEW(sv->priv->view), FALSE);
-	sv->priv->tag_window = sourceview_tags_new(plugin);
-	sv->priv->autocomplete = sourceview_autocomplete_new();
-	sv->priv->args = sourceview_args_new(plugin, sv->priv->view);
-	sv->priv->scope = sourceview_scope_new(plugin, sv->priv->view);
-	anjuta_view_register_completion(sv->priv->view, TAG_WINDOW(sv->priv->tag_window));
-	anjuta_view_register_completion(sv->priv->view, TAG_WINDOW(sv->priv->args));
-	anjuta_view_register_completion(sv->priv->view, TAG_WINDOW(sv->priv->scope));
-	anjuta_view_register_completion(sv->priv->view, TAG_WINDOW(sv->priv->autocomplete));
+	g_object_ref(sv->priv->view);
+	
+	/* VFS monitor */
+	sv->priv->last_saved_content = NULL;
 	
 	/* Apply Preferences */
 	g_object_get(G_OBJECT(plugin), "shell", &shell, NULL);
@@ -510,6 +525,8 @@ sourceview_new(const gchar* uri, const gchar* filename, AnjutaPlugin* plugin)
 	/* Create Higlight Tag */
 	sourceview_create_highligth_indic(sv);
 	
+	DEBUG_PRINT("============ Creating new editor =============");
+	
 	return sv;
 }
 
@@ -520,9 +537,9 @@ static void
 ifile_open (IAnjutaFile* file, const gchar *uri, GError** e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(file);
-	// const gchar* lang;
-	// IAnjutaLanguageSupport* lang_support;
 	sourceview_remove_monitor(sv);
+	/* Hold a reference here to avoid a destroyed editor */
+	g_object_ref(G_OBJECT(sv));
 	anjuta_document_load(sv->priv->document, uri, NULL,
 						 -1, FALSE);
 }
@@ -544,7 +561,8 @@ ifile_savable_save (IAnjutaFileSavable* file, GError** e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(file);
 	sourceview_remove_monitor(sv);
-					 
+	
+	g_object_ref(G_OBJECT(sv));
 	anjuta_document_save(sv->priv->document, 0);
 }
 
@@ -552,9 +570,18 @@ ifile_savable_save (IAnjutaFileSavable* file, GError** e)
 static void 
 ifile_savable_save_as (IAnjutaFileSavable* file, const gchar *uri, GError** e)
 {
+	GtkTextIter start_iter;
+	GtkTextIter end_iter;
 	Sourceview* sv = ANJUTA_SOURCEVIEW(file);
 	sourceview_remove_monitor(sv);
 	/* TODO: Set correct encoding */
+	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER(sv->priv->document),
+								&start_iter, &end_iter);
+	g_free(sv->priv->last_saved_content);
+	sv->priv->last_saved_content = gtk_text_buffer_get_slice (
+															  GTK_TEXT_BUFFER(sv->priv->document),
+															  &start_iter, &end_iter, TRUE);
+	g_object_ref(G_OBJECT(sv));
 	anjuta_document_save_as(sv->priv->document, 
 							uri, anjuta_encoding_get_current(), 0);
 	if (sv->priv->filename)
@@ -691,21 +718,6 @@ static gchar* ieditor_get_text(IAnjutaEditor* editor, gint position,
 									&start_iter, &end_iter, TRUE);
 }
 
-static IAnjutaEditorAttribute*
-ieditor_get_attributes(IAnjutaEditor* editor, 
-					   gint positon, gint length, GError **e)
-{
-	gint i;
-	IAnjutaEditorAttribute *attribs = g_new0(IAnjutaEditorAttribute, length);
-	
-	for (i = 0; i < length; i++)
-	{
-		/* FIXME */
-		attribs[i] = IANJUTA_EDITOR_TEXT;
-	}
-	return attribs;
-}
-
 /* Get cursor position */
 static gint ieditor_get_position(IAnjutaEditor* editor, GError **e)
 {
@@ -962,11 +974,10 @@ ieditor_iface_init (IAnjutaEditorIface *iface)
 	iface->set_tabsize = ieditor_set_tab_size;
 	iface->get_use_spaces = ieditor_get_use_spaces;
 	iface->set_use_spaces = ieditor_set_use_spaces;
-  iface->set_auto_indent = ieditor_set_auto_indent;
+    iface->set_auto_indent = ieditor_set_auto_indent;
 	iface->goto_line = ieditor_goto_line;
 	iface->goto_position = ieditor_goto_position;
 	iface->get_text = ieditor_get_text;
-  iface->get_attributes = ieditor_get_attributes;
 	iface->get_position = ieditor_get_position;
 	iface->get_lineno = ieditor_get_lineno;
 	iface->get_length = ieditor_get_length;
@@ -998,8 +1009,9 @@ set_select(Sourceview* sv, GtkTextIter* start_iter, GtkTextIter* end_iter)
 									  "insert", start_iter);
 	gtk_text_buffer_move_mark_by_name(GTK_TEXT_BUFFER(sv->priv->document),
 									  "selection_bound", end_iter);
-	gtk_text_view_scroll_mark_onscreen(GTK_TEXT_VIEW(sv->priv->view),
-		 gtk_text_buffer_get_insert(GTK_TEXT_BUFFER(sv->priv->document)));			
+	gtk_text_view_scroll_to_mark(GTK_TEXT_VIEW(sv->priv->view),
+								 gtk_text_buffer_get_insert(GTK_TEXT_BUFFER(sv->priv->document)),
+								 0,  FALSE, 0, 0);			
 }
 
 /* IAnjutaEditorSelection */
@@ -1266,31 +1278,6 @@ iconvert_iface_init(IAnjutaEditorConvertIface* iface)
 	iface->to_lower = iconvert_to_lower;
 }
 
-
-/* IAnjutaAssist Interface */
-static void 
-iassist_autocomplete(IAnjutaEditorAssist* edit, GError** ee)
-{
-    Sourceview* sv = ANJUTA_SOURCEVIEW(edit);
-    
-    if (tag_window_update(TAG_WINDOW(sv->priv->autocomplete), GTK_WIDGET(sv->priv->view)))
-    	gtk_widget_show(GTK_WIDGET(sv->priv->autocomplete));
-}
-
-static void iassist_iface_init(IAnjutaEditorAssistIface* iface)
-{
-	iface->autocomplete = iassist_autocomplete;
-}
-
-/* Marker Struture to connect handles and markers */
-typedef struct
-{
-	gint handle;
-	GtkSourceMarker* marker;
-	gint location;
-	IAnjutaMarkableMarker type;
-} SVMarker;
-
 static gint
 imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 		   GError **e)
@@ -1299,6 +1286,7 @@ imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 	GtkTextIter iter;
 	GtkSourceMarker* source_marker;
 	gchar* name;
+	static gint marker_count = 0;
 	
 	gtk_text_buffer_get_iter_at_line(GTK_TEXT_BUFFER(sv->priv->document),
 									 &iter, location  - 1);
@@ -1326,15 +1314,12 @@ imark_mark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 		
 	source_marker = gtk_source_buffer_create_marker(GTK_SOURCE_BUFFER(sv->priv->document), 
 													NULL, name, &iter);
-	SVMarker* sv_marker = g_new0(SVMarker, 1);
-	sv_marker->handle = sv->priv->marker_count++;
-	sv_marker->marker = source_marker;
-	sv_marker->location = location;
-	sv_marker->type = marker;
+
+	g_object_set_data(G_OBJECT(source_marker), "handle", GINT_TO_POINTER(marker_count++));
+	g_object_set_data(G_OBJECT(source_marker), "type", GINT_TO_POINTER(marker));
+	g_object_set_data(G_OBJECT(source_marker), "location", GINT_TO_POINTER(location));
 	
-	sv->priv->markers = g_list_append(sv->priv->markers, sv_marker);
-	
-	return sv_marker->handle;
+	return marker_count;
 }
 
 static void
@@ -1342,19 +1327,16 @@ imark_unmark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 			 GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
-	GList* node = sv->priv->markers;
-	while (node)
+	GtkSourceBuffer* buffer = GTK_SOURCE_BUFFER(sv->priv->document);
+	GtkSourceMarker* smarker;
+	for (smarker = gtk_source_buffer_get_first_marker(buffer);
+		 smarker != NULL; smarker = gtk_source_marker_next(smarker))
 	{
-		SVMarker* sv_marker = node->data;
-		if (sv_marker->location == location)
-		{
-			gtk_source_buffer_delete_marker(GTK_SOURCE_BUFFER(sv->priv->document),
-											sv_marker->marker);
-			sv->priv->markers = g_list_remove(sv->priv->markers, node->data);
-			return;
-		}
-		node = g_list_next(node);
-	}	
+		int marker_location = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(smarker), "location"));
+		if (marker_location == location)
+			gtk_source_buffer_delete_marker(buffer, smarker);
+		/* We do not break here because there might be multiple markers at this location */
+	}
 }
 
 static gboolean
@@ -1362,15 +1344,14 @@ imark_is_marker_set(IAnjutaMarkable* mark, gint location,
 					IAnjutaMarkableMarker marker, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
-	GList* node = sv->priv->markers;
-	while (node)
+	GtkSourceBuffer* buffer = GTK_SOURCE_BUFFER(sv->priv->document);
+	GtkSourceMarker* smarker;
+	for (smarker = gtk_source_buffer_get_first_marker(buffer);
+		 smarker != NULL; smarker = gtk_source_marker_next(smarker))
 	{
-		SVMarker* sv_marker = node->data;
-		if (sv_marker->location == location)
-		{
+		int marker_location = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(smarker), "location"));
+		if (marker_location == location)
 			return TRUE;
-		}
-		node = g_list_next(node);
 	}
 	return FALSE;
 }
@@ -1379,17 +1360,16 @@ static gint
 imark_location_from_handle(IAnjutaMarkable* mark, gint handle, GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
-	GList* node = sv->priv->markers;
-	while (node)
+	GtkSourceBuffer* buffer = GTK_SOURCE_BUFFER(sv->priv->document);
+	GtkSourceMarker* marker;
+	for (marker = gtk_source_buffer_get_first_marker(buffer);
+		 marker != NULL; marker = gtk_source_marker_next(marker))
 	{
-		SVMarker* sv_marker = node->data;
-		if (sv_marker->handle == handle)
-		{
-			return sv_marker->location;
-		}
-		node = g_list_next(node);
+		int marker_handle = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(marker), "handle"));
+		if (marker_handle == handle)
+			return GPOINTER_TO_INT(g_object_get_data(G_OBJECT(marker), "location"));
 	}
-	return FALSE;
+	return 0;
 }
 
 static void
@@ -1397,18 +1377,15 @@ imark_delete_all_markers(IAnjutaMarkable* mark, IAnjutaMarkableMarker marker,
 						 GError **e)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(mark);
-	GList* node = sv->priv->markers;
-	while (node)
+	GtkSourceBuffer* buffer = GTK_SOURCE_BUFFER(sv->priv->document);
+	GtkSourceMarker* smarker;
+	for (smarker = gtk_source_buffer_get_first_marker(buffer);
+		 smarker != NULL; smarker = gtk_source_marker_next(smarker))
 	{
-		SVMarker* sv_marker = node->data;
-		if (sv_marker->type == marker)
-		{
-			gtk_source_buffer_delete_marker(GTK_SOURCE_BUFFER(sv->priv->document),
-											sv_marker->marker);
-			sv->priv->markers = g_list_delete_link(sv->priv->markers, node);
-			node = sv->priv->markers;
-		}
-		node = g_list_next(node);
+		IAnjutaMarkableMarker type = 
+			GPOINTER_TO_INT(g_object_get_data(G_OBJECT(smarker), "type"));
+		if (type == marker)
+			gtk_source_buffer_delete_marker(buffer, smarker);
 	}
 }
 
@@ -1764,7 +1741,7 @@ ANJUTA_TYPE_ADD_INTERFACE(ieditor, IANJUTA_TYPE_EDITOR);
 ANJUTA_TYPE_ADD_INTERFACE(imark, IANJUTA_TYPE_MARKABLE);
 ANJUTA_TYPE_ADD_INTERFACE(iindic, IANJUTA_TYPE_INDICABLE);
 ANJUTA_TYPE_ADD_INTERFACE(iselect, IANJUTA_TYPE_EDITOR_SELECTION);
-ANJUTA_TYPE_ADD_INTERFACE(iassist, IANJUTA_TYPE_EDITOR_ASSIST);
+//ANJUTA_TYPE_ADD_INTERFACE(iassist, IANJUTA_TYPE_EDITOR_ASSIST);
 ANJUTA_TYPE_ADD_INTERFACE(iconvert, IANJUTA_TYPE_EDITOR_CONVERT);
 ANJUTA_TYPE_ADD_INTERFACE(ibookmark, IANJUTA_TYPE_BOOKMARK);
 ANJUTA_TYPE_ADD_INTERFACE(iprint, IANJUTA_TYPE_PRINT);
